:orphan:



.. _sphx_glr_source_auto_examples:

ACT Example Gallery
===================

Different examples on how to read and visualize data using ACT are provided 
here.




.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to make a Skew-T plot from a sounding.">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_skewt_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_skewt_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/skewt_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to download and plot ceiliometer data from the SGP site over Oklahoma...">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_ceil_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_ceil_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/ceil_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to display wind rose and barb timeseries from multiple days worth of ...">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_rh_timeseries_thumb.png

        :ref:`sphx_glr_source_auto_examples_plot_rh_timeseries.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_rh_timeseries

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is a simple example for how to plot a timeseries of sounding data from the ARM SGP site.">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_sonde_thumb.png

        :ref:`sphx_glr_source_auto_examples_plot_sonde.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_sonde

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to display wind rose and barb timeseries from multiple days worth of ...">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_wind_rose_thumb.png

        :ref:`sphx_glr_source_auto_examples_plot_wind_rose.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_wind_rose

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to prepare and plot data for a contour plot">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_plot_contour_thumb.png

        :ref:`sphx_glr_source_auto_examples_plot_contour.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/plot_contour

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to retrieve CAPE, CIN, and lifted index from a sounding.">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_get_stability_indices_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_get_stability_indices_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/get_stability_indices_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to download and plot multiple datasets at a time.">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_multidata_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_multidata_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/multidata_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="In this example, the VISST">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_twod_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_twod_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/twod_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to calculate a weighted average from the MET TBRG, ORG and PWD.  This...">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_weighted_average_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_weighted_average_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/weighted_average_example

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This is an example of how to use existing or create new quality control varibles. All the tests...">

.. only:: html

    .. figure:: /source/auto_examples/images/thumb/sphx_glr_qc_example_thumb.png

        :ref:`sphx_glr_source_auto_examples_qc_example.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /source/auto_examples/qc_example
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//Users/atheisen/Code/ACT/docs/source/source/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//Users/atheisen/Code/ACT/docs/source/source/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
